:py:mod:`piel.models.frequency.photonic.mmi1x2`
===============================================

.. py:module:: piel.models.frequency.photonic.mmi1x2


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.mmi1x2.mmi1x2_50_50



.. py:function:: mmi1x2_50_50()
